@@ -3,6 +3,7 @@ import logging
 import os
 import shutil
 import subprocess
+import sys
 import time
 
 import mkdocs
@@ -53,14 +54,25 @@ class DiagramsPlugin(mkdocs.plugins.BasePlugin):
         # dest_dir = os.path.dirname(file.abs_dest_path)
         # filename = file.abs_dest_path[len(dest_dir)+1:]
         dest_dir = os.path.dirname(file.abs_src_path)
-        filename = file.abs_src_path[len(dest_dir) + 1 :]
+        filename = file.abs_src_path[len(dest_dir) + 1:]
 
         # Even when writing in abs_src_path rather than abs_dest_path, this
         # seems needed to make livereload accurately pick up changes.
         os.makedirs(os.path.dirname(file.abs_dest_path), exist_ok=True)
         shutil.copy(file.abs_src_path, file.abs_dest_path)
 
-        subprocess.run(["python", filename], check=True, cwd=dest_dir)
+        # Try to get the full path to the currently used interpreter. This
+        # helps ensure we use the right one even with virtualenvs, etc.,
+        # especially on Windows.
+        # (See https://github.com/zoni/mkdocs-diagrams/issues/2)
+        python_path = sys.executable
+
+        # If Python is unable to retrieve the real path to its
+        # executable, sys.executable will be an empty string or None.
+        if python_path is None or python_path == "":
+            python_path = "python"
+
+        subprocess.run([python_path, filename], check=True, cwd=dest_dir)
 
     def _walk_files_and_render(self, config):
         pool = self._create_threadpool()
